@@ -1,10 +1,21 @@
 package Net::IPAM::IP;
 
+our $VERSION = '1.15';
+
+use 5.10.0;
 use strict;
 use warnings;
-our $VERSION = '1.14';
+use utf8;
 
+use Carp qw/croak/;
 use Socket qw/:addrinfo AF_INET AF_INET6 AF_UNSPEC SOCK_RAW/;
+####
+use namespace::clean;
+
+use overload
+  '""'     => sub { shift->to_string },
+  bool     => sub { 1 },
+  fallback => 1;
 
 # On some platforms, inet_pton accepts various forms of invalid input or discards valid input.
 # In this case use a (slower) pure-perl implementation for Socket::inet_pton.
@@ -28,15 +39,6 @@ BEGIN {
   }
 }
 
-use Carp qw/croak/;
-use Exporter 'import';
-our @EXPORT_OK = qw(incr_n);
-
-use overload
-  '""'     => sub { shift->to_string },
-  bool     => sub { 1 },
-  fallback => 1;
-
 =head1 NAME
 
 Net::IPAM::IP - A library for reading, formatting, sorting and converting IP-addresses.
@@ -306,7 +308,7 @@ Returns the input string in canonical form.
 
 Stringification is overloaded with L</"to_string">
 
-  my $ip = Net::IPAM::IP->new('Fe80::0001') // die 'wrong format,';;
+  my $ip = Net::IPAM::IP->new('Fe80::0001') // die 'wrong format';
   say $ip; # fe80::1
 
 =cut
@@ -466,6 +468,22 @@ sub getname {
   return $name;
 }
 
+=head1 OPERATORS
+
+L<Net::IPAM::IP> overloads the following operators.
+
+=head2 bool
+
+  my $bool = !!$ip;
+
+Always true.
+
+=head2 stringify
+
+  my $str = "$ip";
+
+Alias for L</"to_string">.
+
 =head1 FUNCTIONS
 
 L<Net::IPAM::IP> implements the following functions;
@@ -610,22 +628,6 @@ sub _inet_pton_v6_pp {
   return $n;
 }
 
-=head1 OPERATORS
-
-L<Net::IPAM::IP> overloads the following operators.
-
-=head2 bool
-
-  my $bool = !!$ip;
-
-Always true.
-
-=head2 stringify
-
-  my $str = "$ip";
-
-Alias for L</"to_string">.
-
 =head1 WARNING
 
 Some Socket::inet_XtoY implementations are hopelessly buggy.
